km3pipe\.dataclasses\.McHitSeries
=================================

.. currentmodule:: km3pipe.dataclasses

.. autoclass:: McHitSeries

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~McHitSeries.__init__
      ~McHitSeries.append_fields
      ~McHitSeries.conv_from
      ~McHitSeries.conv_to
      ~McHitSeries.deserialise
      ~McHitSeries.from_aanet
      ~McHitSeries.from_arrays
      ~McHitSeries.from_dict
      ~McHitSeries.from_evt
      ~McHitSeries.from_table
      ~McHitSeries.next
      ~McHitSeries.serialise
      ~McHitSeries.sorted
   
   

   
   
   